==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/javascript2.jquery/test/unit/src/org/netbeans/modules/javascript2/jquery/JQueryCodeCompletionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.javascript2.jquery;

import org.netbeans.modules.javascript2.editor.JsCodeCompletionBase;

/**
 *
 * @author Petr Hejl, Petr Pisl
 */
public class JQueryCodeCompletionTest extends JsCodeCompletionBase {

    public JQueryCodeCompletionTest(String testName) {
        super(testName);
    }

    public void testProperty01() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "^jQuery.event.customEvent.test();", false);
    }

    public void testProperty02() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.^event.customEvent.test();", false);
    }

    public void testProperty03() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.event.^customEvent.test();", false);
    }

    public void testProperty04() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.event.customEvent.^test();", false);
    }

    public void testProperty05() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.ajaxStart().add^Class();", false);
    }

    public void testIssue217123() throws Exception {
        checkCompletion("testfiles/completion/issue217123.html", "$(\"#text\").ani^", false);
    }

    public void testIssue217450() throws Exception {
        checkCompletion("testfiles/completion/issue217450.js", "$(\"#text\").^", false);
    }

    public void testMethods01() throws Exception {
        checkCompletion("testfiles/completion/jQuery/simple.js", "jQuery('#test').a^ddClass('.myClass');", false);
    }

    public void testMethods02() throws Exception {
        checkCompletion("testfiles/completion/jQuery/simple.js", "$('#test').ad^dClass('.myClass');", false);
    }

    public void testNewFile() throws Exception {
        checkCompletion("testfiles/completion/jQuery/newFile.js", "jQuery('#f-emblem').a^ddClass('.has-menu');", false);
    }

    public void testNewFile02() throws Exception {
        checkCompletion("testfiles/completion/jQuery/newFile.js", "jQuery('#f-emblem').addClass('.has-menu').a^dd(':checked');", false);
    }

    public void testIssue223963() throws Exception {
        checkCompletionDocumentation("testfiles/completion/jQuery/issue223963.js", "$(document).a^", false, "a");
    }

    public void testIssue223060() throws Exception {
        checkCompletion("testfiles/completion/jQuery/issue223060.js", "form.^", false);
    }
    
    public void testIssue235647() throws Exception {
        checkCompletion("testfiles/completion/issue235647.js", "$.po^", false);
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/javascript2.jquery/test/unit/src/org/netbeans/modules/javascript2/jquery/JQueryCodeCompletionTest.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.javascript2.jquery;

import org.netbeans.modules.javascript2.editor.JsCodeCompletionBase;

/**
 *
 * @author Petr Hejl, Petr Pisl
 */
public class JQueryCodeCompletionTest extends JsCodeCompletionBase {

    public JQueryCodeCompletionTest(String testName) {
        super(testName);
    }

    public void testProperty01() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "^jQuery.event.customEvent.test();", false);
    }

    public void testProperty02() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.^event.customEvent.test();", false);
    }

    public void testProperty03() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.event.^customEvent.test();", false);
    }

    public void testProperty04() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.event.customEvent.^test();", false);
    }

    public void testProperty05() throws Exception {
        checkCompletion("testfiles/completion/jQueryFragment01.js", "jQuery.ajaxStart().add^Class();", false);
    }

    public void testIssue217123() throws Exception {
        checkCompletion("testfiles/completion/issue217123.html", "$(\"#text\").ani^", false);
    }

    public void testIssue217450() throws Exception {
        checkCompletion("testfiles/completion/issue217450.js", "$(\"#text\").^", false);
    }

    public void testMethods01() throws Exception {
        checkCompletion("testfiles/completion/jQuery/simple.js", "jQuery('#test').a^ddClass('.myClass');", false);
    }

    public void testMethods02() throws Exception {
        checkCompletion("testfiles/completion/jQuery/simple.js", "$('#test').ad^dClass('.myClass');", false);
    }

    public void testNewFile() throws Exception {
        checkCompletion("testfiles/completion/jQuery/newFile.js", "jQuery('#f-emblem').a^ddClass('.has-menu');", false);
    }

    public void testNewFile02() throws Exception {
        checkCompletion("testfiles/completion/jQuery/newFile.js", "jQuery('#f-emblem').addClass('.has-menu').a^dd(':checked');", false);
    }

    public void testIssue223963() throws Exception {
        checkCompletionDocumentation("testfiles/completion/jQuery/issue223963.js", "$(document).a^", false, "a");
    }

    public void testIssue223060() throws Exception {
        checkCompletion("testfiles/completion/jQuery/issue223060.js", "form.^", false);
    }
    
    public void testIssue235647() throws Exception {
        checkCompletion("testfiles/completion/issue235647.js", "$.po^", false);
    }
    
    public void testIssue249169() throws Exception {
        checkCompletion("testfiles/completion/issue249169.js", "if ($(\":an^\")) {", false);
    }
}
